@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id$ */
+/* $Id: accelmap.cc 1066 2008-12-10 19:45:14Z murrayc $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -19,7 +19,7 @@
  */
 
 #include <gtkmm/accelmap.h>
-#include <gtk/gtkaccelmap.h>
+#include <gtk/gtk.h>
 
 namespace Gtk
 {
