@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: comboboxtext.cc 404 2005-05-03 17:01:16Z murrayc $ */
+/* $Id: comboboxtext.cc 1066 2008-12-10 19:45:14Z murrayc $ */
 
 /* 
  *
@@ -24,8 +24,7 @@
 
 #include <gtkmm/liststore.h>
 #include <gtkmm/cellrenderertext.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtkcelllayout.h>
+#include <gtk/gtk.h>
 
 namespace Gtk
 {
